@@ -4,7 +4,7 @@ use Mojolicious::Plugin::AssetPack::Asset::Null;
 use Mojolicious::Plugin::AssetPack::Store;
 use Mojolicious::Plugin::AssetPack::Util qw(diag has_ro load_module DEBUG);
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 has minify => sub { shift->_app->mode eq 'development' ? 0 : 1 };
 
@@ -94,6 +94,9 @@ sub register {
     $app->helper($helper => sub { @_ == 1 ? $self : $self->_tag_helpers(@_) });
   }
   else {
+    $app->log->warn('Loading DEPRECATED Mojolicious::Plugin::AssetPack::Backcompat.');
+    Test::More::diag("Loading DEPRECATED Mojolicious::Plugin::AssetPack::Backcompat.")
+      if $ENV{HARNESS_ACTIVE} and UNIVERSAL::can(qw(Test::More diag));
     require Mojolicious::Plugin::AssetPack::Backcompat;
     @Mojolicious::Plugin::AssetPack::ISA = ('Mojolicious::Plugin::AssetPack::Backcompat');
     return $self->SUPER::register($app, $config);
@@ -190,12 +193,13 @@ sub _tag_helpers {
     or die qq(No assets registered by topic "$topic".);
 
   $base_url =~ s!/+$!!;
+  $base_url = Mojo::URL->new($base_url) if $base_url;
 
   return $assets->grep(sub { !$_->isa('Mojolicious::Plugin::AssetPack::Asset::Null') })
     ->map(
     sub {
       my $tag_helper = $_->format eq 'js' ? 'javascript' : 'stylesheet';
-      my $url = $base_url . $route->render($_->TO_JSON);
+      my $url = Mojo::URL->new($base_url . $c->url_for(assetpack => $_->TO_JSON));
       $c->$tag_helper($url, @attrs);
     }
     )->join("\n");
@@ -216,7 +220,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-1.06
+1.07
 
 =head1 SYNOPSIS
 
